==> zio-aws-codeguruprofiler_3-5.17.154.1-sources.jar: zio/aws/codeguruprofiler/model/AddNotificationChannelsResponse.scala <==
package zio.aws.codeguruprofiler.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class AddNotificationChannelsResponse(
    notificationConfiguration: Option[
      zio.aws.codeguruprofiler.model.NotificationConfiguration
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codeguruprofiler.model.AddNotificationChannelsResponse = {
    import AddNotificationChannelsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codeguruprofiler.model.AddNotificationChannelsResponse
      .builder()
      .optionallyWith(
        notificationConfiguration.map(value => value.buildAwsValue())
      )(_.notificationConfiguration)
      .build()
  }
  def asReadOnly
      : zio.aws.codeguruprofiler.model.AddNotificationChannelsResponse.ReadOnly =
    zio.aws.codeguruprofiler.model.AddNotificationChannelsResponse
      .wrap(buildAwsValue())
}
object AddNotificationChannelsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codeguruprofiler.model.AddNotificationChannelsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.codeguruprofiler.model.AddNotificationChannelsResponse =
      zio.aws.codeguruprofiler.model.AddNotificationChannelsResponse(
        notificationConfiguration.map(value => value.asEditable)
      )
    def notificationConfiguration: Option[
      zio.aws.codeguruprofiler.model.NotificationConfiguration.ReadOnly
    ]
    def getNotificationConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.codeguruprofiler.model.NotificationConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "notificationConfiguration",
      notificationConfiguration
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codeguruprofiler.model.AddNotificationChannelsResponse
  ) extends zio.aws.codeguruprofiler.model.AddNotificationChannelsResponse.ReadOnly {
    override val notificationConfiguration: Option[
      zio.aws.codeguruprofiler.model.NotificationConfiguration.ReadOnly
    ] = scala
      .Option(impl.notificationConfiguration())
      .map(value =>
        zio.aws.codeguruprofiler.model.NotificationConfiguration.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.codeguruprofiler.model.AddNotificationChannelsResponse
  ): zio.aws.codeguruprofiler.model.AddNotificationChannelsResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-codeguruprofiler_3-7.21.15.12-sources.jar: zio/aws/codeguruprofiler/model/AddNotificationChannelsResponse.scala <==
package zio.aws.codeguruprofiler.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class AddNotificationChannelsResponse(
    notificationConfiguration: Optional[
      zio.aws.codeguruprofiler.model.NotificationConfiguration
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codeguruprofiler.model.AddNotificationChannelsResponse = {
    import AddNotificationChannelsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codeguruprofiler.model.AddNotificationChannelsResponse
      .builder()
      .optionallyWith(
        notificationConfiguration.map(value => value.buildAwsValue())
      )(_.notificationConfiguration)
      .build()
  }
  def asReadOnly
      : zio.aws.codeguruprofiler.model.AddNotificationChannelsResponse.ReadOnly =
    zio.aws.codeguruprofiler.model.AddNotificationChannelsResponse
      .wrap(buildAwsValue())
}
object AddNotificationChannelsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codeguruprofiler.model.AddNotificationChannelsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.codeguruprofiler.model.AddNotificationChannelsResponse =
      zio.aws.codeguruprofiler.model.AddNotificationChannelsResponse(
        notificationConfiguration.map(value => value.asEditable)
      )
    def notificationConfiguration: Optional[
      zio.aws.codeguruprofiler.model.NotificationConfiguration.ReadOnly
    ]
    def getNotificationConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.codeguruprofiler.model.NotificationConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "notificationConfiguration",
      notificationConfiguration
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codeguruprofiler.model.AddNotificationChannelsResponse
  ) extends zio.aws.codeguruprofiler.model.AddNotificationChannelsResponse.ReadOnly {
    override val notificationConfiguration: Optional[
      zio.aws.codeguruprofiler.model.NotificationConfiguration.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.notificationConfiguration())
      .map(value =>
        zio.aws.codeguruprofiler.model.NotificationConfiguration.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.codeguruprofiler.model.AddNotificationChannelsResponse
  ): zio.aws.codeguruprofiler.model.AddNotificationChannelsResponse.ReadOnly =
    new Wrapper(impl)
}
